# coding: utf-8

"""
    GraphQL support

    GraphQL endpoint to query Knowledge Graphs

    The version of the OpenAPI document: 1.0
    Contact: hello@wordlift.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from wordlift_client.api.include_excludes_api import IncludeExcludesApi


class TestIncludeExcludesApi(unittest.TestCase):
    """IncludeExcludesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = IncludeExcludesApi()

    def tearDown(self) -> None:
        pass

    def test_list_include_excludes(self) -> None:
        """Test case for list_include_excludes

        List
        """
        pass

    def test_update_include_excludes(self) -> None:
        """Test case for update_include_excludes

        Update
        """
        pass


if __name__ == '__main__':
    unittest.main()
