# coding: utf-8

"""
    Analysis

    Analyse content using Linked Data and Knowledge Graphs.

    The version of the OpenAPI document: 1.0
    Contact: hello@wordlift.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from wordlift_client.api.content_generation_records_api import ContentGenerationRecordsApi


class TestContentGenerationRecordsApi(unittest.TestCase):
    """ContentGenerationRecordsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ContentGenerationRecordsApi()

    def tearDown(self) -> None:
        pass

    def test_get_record(self) -> None:
        """Test case for get_record

        Get
        """
        pass

    def test_list_records(self) -> None:
        """Test case for list_records

        List
        """
        pass

    def test_list_records_as_events(self) -> None:
        """Test case for list_records_as_events

        List as Events
        """
        pass

    def test_update_record(self) -> None:
        """Test case for update_record

        Update
        """
        pass

    def test_update_records(self) -> None:
        """Test case for update_records

        Update
        """
        pass

    def test_update_records_collection(self) -> None:
        """Test case for update_records_collection

        Update
        """
        pass


if __name__ == '__main__':
    unittest.main()
