# coding: utf-8

"""
    Analysis

    Analyse content using Linked Data and Knowledge Graphs.

    The version of the OpenAPI document: 1.0
    Contact: hello@wordlift.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from wordlift_client.models.question_and_answer_request import QuestionAndAnswerRequest

class TestQuestionAndAnswerRequest(unittest.TestCase):
    """QuestionAndAnswerRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> QuestionAndAnswerRequest:
        """Test QuestionAndAnswerRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `QuestionAndAnswerRequest`
        """
        model = QuestionAndAnswerRequest()
        if include_optional:
            return QuestionAndAnswerRequest(
                smart_content_id = 56,
                webpage_properties = wordlift_client.models.webpage_properties.WebpageProperties(
                    entities = [
                        ''
                        ], 
                    iri = '', 
                    query = '', 
                    url = '', )
            )
        else:
            return QuestionAndAnswerRequest(
        )
        """

    def testQuestionAndAnswerRequest(self):
        """Test QuestionAndAnswerRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
