# coding: utf-8

"""
    Analysis

    Analyse content using Linked Data and Knowledge Graphs.

    The version of the OpenAPI document: 1.0
    Contact: hello@wordlift.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from wordlift_client.models.analyses_request import AnalysesRequest

class TestAnalysesRequest(unittest.TestCase):
    """AnalysesRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AnalysesRequest:
        """Test AnalysesRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AnalysesRequest`
        """
        model = AnalysesRequest()
        if include_optional:
            return AnalysesRequest(
                text = '',
                url = '',
                query = '',
                html = '',
                language_code = 'en',
                query_location_name = 'United States',
                query_search_engine = 'google.co.uk',
                linked_data = True,
                local_data = True,
                network_data = True
            )
        else:
            return AnalysesRequest(
        )
        """

    def testAnalysesRequest(self):
        """Test AnalysesRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
